{% extends "base.html" %}

{% block html_title %}Client list{% endblock %}

{% block page_title %}Client list{% endblock %}

{% block content %}
        <table border="1">
            <tr>
                <td>
                    <b>Hostname</b>
                </td>
                <td>
                    <b>Address</b>
                </td>
                <td>
                    <b>Available</b>
                </td>
                <td>
                    <b>Has xsanio_client installed</b>
                </td>
            </tr>
            {% for object in object_list %}
                <tr>
                    <td>
                        <a href="{% url client_detail_view object.id %}">{{ object.host_name }}</a>
                    </td>
                    <td>
                        {{ object.ip_address }}
                    </td>
                    <td>
                        {{ object.is_unreachable|yesno:"No,Yes" }}
                    </td>
                    <td>
                        {% if object.has_client_installed %}
                            Yes
                        {% else %}
                            <p style="color:red">No</p>
                        {% endif %}
                    </td>
                </tr>
            {% endfor %}
        </table>
        <p><a href="{% url home_view %}">Home</a></p>
{% endblock %}
