{% extends "base.html" %}

{% block html_title %}Xsan I/O Monitoring{% endblock %}

{% block page_title %}Xsan I/O Monitoring{% endblock %}

{% block content %}
        <p><a href='{% url volume_list_view %}'>Volume list</a></p>
        <p><a href='{% url client_list_view %}'>Client list</a></p>
{% endblock %}

{% block footer %}
{% endblock %}